@@ -6,10 +6,11 @@ from qualang_tools.bakery.randomized_benchmark import (
     find_revert_op,
     RBSequence,
 )
-from qualang_tools.config_tools.integration_weights_tools import (
+from qualang_tools.config.integration_weights_tools import (
     convert_integration_weights,
     compress_integration_weights,
 )
+from qualang_tools.simulator_tools import create_simulator_controller_connections
 
 __all__ = [
     "baking",
@@ -21,4 +22,5 @@ __all__ = [
     "XEBOpsSingleQubit",
     "convert_integration_weights",
     "compress_integration_weights",
+    "create_simulator_controller_connections",
 ]
